"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CallbackQuery = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const message_1 = require("./message");
const user_1 = require("./user");
const inaccessible_message_1 = require("./inaccessible-message");
const helpers_1 = require("../../utils/helpers");
/**
 * This object represents an incoming callback query from a callback button in
 * an inline keyboard. If the button that originated the query was attached to
 * a message sent by the bot, the field message will be present.
 * If the button was attached to a message sent via the bot (in inline mode),
 * the field inline_message_id will be present.
 * Exactly one of the fields `data` or `game_short_name` will be present.
 */
let CallbackQuery = class CallbackQuery {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Unique identifier for this query */
    get id() {
        return this.payload.id;
    }
    /** Sender */
    get from() {
        return new user_1.User(this.payload.from);
    }
    /** Sender ID */
    get senderId() {
        return this.from.id;
    }
    /**
     * Message sent by the bot with the callback button that originated the query
     */
    get message() {
        const { message } = this.payload;
        if (!message) {
            return;
        }
        if (message.date === 0) {
            return new inaccessible_message_1.InaccessibleMessage(message);
        }
        return new message_1.Message(message);
    }
    /**
     * Identifier of the message sent via the bot in inline mode,
     * that originated the query.
     */
    get inlineMessageId() {
        return this.payload.inline_message_id;
    }
    /**
     * Global identifier, uniquely corresponding to the chat to which the message
     * with the callback button was sent. Useful for high scores in games.
     */
    get chatInstance() {
        return this.payload.chat_instance;
    }
    /**
     * Data associated with the callback button.
     * Be aware that a bad client can send arbitrary data in this field.
     */
    get data() {
        return this.payload.data;
    }
    /**
     * Short name of a Game to be returned,
     * serves as the unique identifier for the game
     */
    get gameShortName() {
        return this.payload.game_short_name;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], CallbackQuery.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], CallbackQuery.prototype, "from", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], CallbackQuery.prototype, "message", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], CallbackQuery.prototype, "inlineMessageId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], CallbackQuery.prototype, "chatInstance", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], CallbackQuery.prototype, "data", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], CallbackQuery.prototype, "gameShortName", null);
CallbackQuery = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], CallbackQuery);
exports.CallbackQuery = CallbackQuery;
(0, helpers_1.memoizeGetters)(CallbackQuery, ['from', 'message']);
