"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExternalReplyInfo = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const attachments_1 = require("../attachments");
const message_origin_1 = require("./message-origin");
const chat_1 = require("./chat");
const link_preview_options_1 = require("./link-preview-options");
const photo_size_1 = require("./photo-size");
const dice_1 = require("./dice");
const poll_1 = require("./poll");
const game_1 = require("./game");
const invoice_1 = require("./invoice");
const location_1 = require("./location");
const venue_1 = require("./venue");
const giveaway_1 = require("./giveaway");
const giveaway_winners_1 = require("./giveaway-winners");
const helpers_1 = require("../../utils/helpers");
/** This object contains information about a message that is being replied to, which may come from another chat or forum topic. */
let ExternalReplyInfo = class ExternalReplyInfo {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Origin of the message replied to by the given message */
    get origin() {
        if (this.payload.origin.type === 'user') {
            return new message_origin_1.MessageOriginUser(this.payload.origin);
        }
        if (this.payload.origin.type === 'chat') {
            return new message_origin_1.MessageOriginChat(this.payload.origin);
        }
        if (this.payload.origin.type === 'channel') {
            return new message_origin_1.MessageOriginChannel(this.payload.origin);
        }
        if (this.payload.origin.type === 'hidden_user') {
            return new message_origin_1.MessageOriginHiddenUser(this.payload.origin);
        }
        throw new TypeError('unknown message origin type');
    }
    /** Chat the original message belongs to. Available only if the chat is a supergroup or a channel. */
    get chat() {
        const { chat } = this.payload;
        if (!chat) {
            return undefined;
        }
        return new chat_1.Chat(chat);
    }
    /** Unique message identifier inside the original chat. Available only if the original chat is a supergroup or a channel. */
    get messageId() {
        return this.payload.message_id;
    }
    /** Options used for link preview generation for the original message, if it is a text message */
    get linkPreviewOptions() {
        const { link_preview_options } = this.payload;
        if (!link_preview_options) {
            return undefined;
        }
        return new link_preview_options_1.LinkPreviewOptions(link_preview_options);
    }
    /** Message is an animation, information about the animation */
    get animation() {
        const { animation } = this.payload;
        if (!animation) {
            return undefined;
        }
        return new attachments_1.AnimationAttachment(animation);
    }
    /** Message is an audio file, information about the file */
    get audio() {
        const { audio } = this.payload;
        if (!audio) {
            return undefined;
        }
        return new attachments_1.AudioAttachment(audio);
    }
    /** Message is a general file, information about the file */
    get document() {
        const { document } = this.payload;
        if (!document) {
            return undefined;
        }
        return new attachments_1.DocumentAttachment(document);
    }
    /** Message is a photo, available sizes of the photo */
    get photo() {
        const { photo } = this.payload;
        if (!photo) {
            return undefined;
        }
        return new attachments_1.PhotoAttachment(photo.map(size => new photo_size_1.PhotoSize(size)));
    }
    /** Message is a sticker, information about the sticker */
    get sticker() {
        const { sticker } = this.payload;
        if (!sticker) {
            return undefined;
        }
        return new attachments_1.StickerAttachment(sticker);
    }
    /** Message is a forwarded story */
    get story() {
        const { story } = this.payload;
        if (!story) {
            return undefined;
        }
        return new attachments_1.StoryAttachment(story);
    }
    /** Message is a video, information about the video */
    get video() {
        const { video } = this.payload;
        if (!video) {
            return undefined;
        }
        return new attachments_1.VideoAttachment(video);
    }
    /** Message is a video note, information about the video message */
    get videoNote() {
        const { video_note } = this.payload;
        if (!video_note) {
            return undefined;
        }
        return new attachments_1.VideoNoteAttachment(video_note);
    }
    /** Message is a voice message, information about the file */
    get voice() {
        const { voice } = this.payload;
        if (!voice) {
            return undefined;
        }
        return new attachments_1.VoiceAttachment(voice);
    }
    /** `true`, if the message media is covered by a spoiler animation */
    hasMediaSpoiler() {
        return this.payload.has_media_spoiler;
    }
    /** Message is a shared contact, information about the contact */
    get contact() {
        const { contact } = this.payload;
        if (!contact) {
            return undefined;
        }
        return new attachments_1.ContactAttachment(contact);
    }
    /** Message is a dice with random value */
    get dice() {
        const { dice } = this.payload;
        if (!dice) {
            return undefined;
        }
        return new dice_1.Dice(dice);
    }
    /** Message is a game, information about the game */
    get game() {
        const { game } = this.payload;
        if (!game) {
            return undefined;
        }
        return new game_1.Game(game);
    }
    /** Message is a scheduled giveaway, information about the giveaway */
    get giveaway() {
        const { giveaway } = this.payload;
        if (!giveaway) {
            return undefined;
        }
        return new giveaway_1.Giveaway(giveaway);
    }
    /** A giveaway with public winners was completed */
    get giveawayWinners() {
        const { giveaway_winners } = this.payload;
        if (!giveaway_winners) {
            return undefined;
        }
        return new giveaway_winners_1.GiveawayWinners(giveaway_winners);
    }
    /** Message is an invoice for a payment, information about the invoice */
    get invoice() {
        const { invoice } = this.payload;
        if (!invoice) {
            return undefined;
        }
        return new invoice_1.Invoice(invoice);
    }
    /** Message is a shared location, information about the location */
    get location() {
        const { location } = this.payload;
        if (!location) {
            return undefined;
        }
        return new location_1.Location(location);
    }
    /** Message is a native poll, information about the poll */
    get poll() {
        const { poll } = this.payload;
        if (!poll) {
            return undefined;
        }
        return new poll_1.Poll(poll);
    }
    /** Message is a venue, information about the venue */
    get venue() {
        const { venue } = this.payload;
        if (!venue) {
            return undefined;
        }
        return new venue_1.Venue(venue);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ExternalReplyInfo.prototype, "origin", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "chat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "messageId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "linkPreviewOptions", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "animation", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "audio", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "document", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "photo", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "sticker", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "story", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "video", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "videoNote", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "voice", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ExternalReplyInfo.prototype, "hasMediaSpoiler", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "contact", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "dice", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "game", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "giveaway", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "giveawayWinners", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "invoice", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "location", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "poll", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ExternalReplyInfo.prototype, "venue", null);
ExternalReplyInfo = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ExternalReplyInfo);
exports.ExternalReplyInfo = ExternalReplyInfo;
(0, helpers_1.memoizeGetters)(ExternalReplyInfo, ['origin', 'chat', 'linkPreviewOptions', 'animation', 'audio', 'document', 'photo', 'sticker', 'story', 'video', 'videoNote', 'voice', 'contact', 'dice', 'game', 'giveaway', 'giveawayWinners', 'invoice', 'location', 'poll', 'venue']);
