"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Update = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const callback_query_1 = require("./callback-query");
const chat_join_request_1 = require("./chat-join-request");
const chat_member_updated_1 = require("./chat-member-updated");
const chosen_inline_result_1 = require("./chosen-inline-result");
const inline_query_1 = require("./inline-query");
const message_1 = require("./message");
const poll_1 = require("./poll");
const poll_answer_1 = require("./poll-answer");
const pre_checkout_query_1 = require("./pre-checkout-query");
const shipping_query_1 = require("./shipping-query");
const message_reaction_updated_1 = require("./message-reaction-updated");
const message_reaction_count_updated_1 = require("./message-reaction-count-updated");
const chat_boost_removed_1 = require("./chat-boost-removed");
const chat_boost_updated_1 = require("./chat-boost-updated");
const helpers_1 = require("../../utils/helpers");
/**
 * This object represents an incoming update.
 *
 * At most **one** of the optional parameters can be present in any given
 * update.
 */
let Update = class Update {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /**
     * The update's unique identifier.
     * Update identifiers start from a certain positive number and increase
     * sequentially. This ID becomes especially handy if you're using
     * **Webhooks**, since it allows you to ignore repeated updates or to restore
     * the correct update sequence, should they get out of order. If there are no
     * new updates for at least a week, then identifier of the next update will
     * be chosen randomly instead of sequentially.
     */
    get id() {
        return this.payload.update_id;
    }
    /**
     * New incoming message of any kind — text, photo, sticker, etc.
     */
    get message() {
        const { message } = this.payload;
        if (!message) {
            return;
        }
        return new message_1.Message(message);
    }
    /** New version of a message that is known to the bot and was edited */
    get editedMessage() {
        const { edited_message } = this.payload;
        if (!edited_message) {
            return;
        }
        return new message_1.Message(edited_message);
    }
    /** New incoming channel post of any kind — text, photo, sticker, etc. */
    get channelPost() {
        const { channel_post } = this.payload;
        if (!channel_post) {
            return;
        }
        return new message_1.Message(channel_post);
    }
    /** New version of a channel post that is known to the bot and was edited */
    get editedChannelPost() {
        const { edited_channel_post } = this.payload;
        if (!edited_channel_post) {
            return;
        }
        return new message_1.Message(edited_channel_post);
    }
    /** A reaction to a message was changed by a user. The bot must be an administrator in the chat and must explicitly specify `message_reaction` in the list of allowed_updates to receive these updates. The update isn't received for reactions set by bots. */
    get messageReaction() {
        const { message_reaction } = this.payload;
        if (!message_reaction) {
            return;
        }
        return new message_reaction_updated_1.MessageReactionUpdated(message_reaction);
    }
    /** Reactions to a message with anonymous reactions were changed. The bot must be an administrator in the chat and must explicitly specify `message_reaction_count` in the list of allowed_updates to receive these updates. */
    get messageReactionCount() {
        const { message_reaction_count } = this.payload;
        if (!message_reaction_count) {
            return;
        }
        return new message_reaction_count_updated_1.MessageReactionCountUpdated(message_reaction_count);
    }
    /** New incoming inline query */
    get inlineQuery() {
        const { inline_query } = this.payload;
        if (!inline_query) {
            return;
        }
        return new inline_query_1.InlineQuery(inline_query);
    }
    /**
     * The result of an inline query that was chosen by a user and sent to their
     * chat partner. Please see our documentation on the feedback collecting for
     * details on how to enable these updates for your bot.
     */
    get chosenInlineResult() {
        const { chosen_inline_result } = this.payload;
        if (!chosen_inline_result) {
            return;
        }
        return new chosen_inline_result_1.ChosenInlineResult(chosen_inline_result);
    }
    /** New incoming callback query */
    get callbackQuery() {
        const { callback_query } = this.payload;
        if (!callback_query) {
            return;
        }
        return new callback_query_1.CallbackQuery(callback_query);
    }
    /** New incoming shipping query. Only for invoices with flexible price */
    get shippingQuery() {
        const { shipping_query } = this.payload;
        if (!shipping_query) {
            return;
        }
        return new shipping_query_1.ShippingQuery(shipping_query);
    }
    /**
     * New incoming pre-checkout query. Contains full information about checkout
     */
    get preCheckoutQuery() {
        const { pre_checkout_query } = this.payload;
        if (!pre_checkout_query) {
            return;
        }
        return new pre_checkout_query_1.PreCheckoutQuery(pre_checkout_query);
    }
    /**
     * New poll state. Bots receive only updates about stopped polls and polls,
     * which are sent by the bot
     */
    get poll() {
        const { poll } = this.payload;
        if (!poll) {
            return;
        }
        return new poll_1.Poll(poll);
    }
    /**
     * A user changed their answer in a non-anonymous poll. Bots receive new
     * votes only in polls that were sent by the bot itself.
     */
    get pollAnswer() {
        const { poll_answer } = this.payload;
        if (!poll_answer) {
            return;
        }
        return new poll_answer_1.PollAnswer(poll_answer);
    }
    /** The bot's chat member status was updated in a chat. For private chats, this update is received only when the bot is blocked or unblocked by the user. */
    get myChatMember() {
        const { my_chat_member } = this.payload;
        if (!my_chat_member) {
            return;
        }
        return new chat_member_updated_1.ChatMemberUpdated(my_chat_member);
    }
    /**
     * A chat member's status was updated in a chat.
     *
     * The bot must be an administrator in the chat and must explicitly specify `chat_member` in the list of `allowed_updates` to receive these updates.
     */
    get chatMember() {
        const { chat_member } = this.payload;
        if (!chat_member) {
            return;
        }
        return new chat_member_updated_1.ChatMemberUpdated(chat_member);
    }
    /** A request to join the chat has been sent. The bot must have the `can_invite_users` administrator right in the chat to receive these updates. */
    get chatJoinRequest() {
        const { chat_join_request } = this.payload;
        if (!chat_join_request) {
            return;
        }
        return new chat_join_request_1.ChatJoinRequest(chat_join_request);
    }
    /** A chat boost was added or changed. The bot must be an administrator in the chat to receive these updates. */
    get chatBoost() {
        const { chat_boost } = this.payload;
        if (!chat_boost) {
            return;
        }
        return new chat_boost_updated_1.ChatBoostUpdated(chat_boost);
    }
    /** A boost was removed from a chat. The bot must be an administrator in the chat to receive these updates. */
    get removedChatBoost() {
        const { removed_chat_boost } = this.payload;
        if (!removed_chat_boost) {
            return;
        }
        return new chat_boost_removed_1.ChatBoostRemoved(removed_chat_boost);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Update.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "message", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "editedMessage", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "channelPost", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "editedChannelPost", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "messageReaction", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "messageReactionCount", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "inlineQuery", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "chosenInlineResult", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "callbackQuery", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "shippingQuery", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "preCheckoutQuery", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "poll", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "pollAnswer", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "myChatMember", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "chatMember", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Update.prototype, "chatJoinRequest", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Update.prototype, "chatBoost", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Update.prototype, "removedChatBoost", null);
Update = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], Update);
exports.Update = Update;
(0, helpers_1.memoizeGetters)(Update, ['message', 'editedMessage', 'channelPost', 'editedChannelPost', 'messageReaction', 'messageReactionCount', 'inlineQuery', 'chosenInlineResult', 'callbackQuery', 'shippingQuery', 'preCheckoutQuery', 'poll', 'pollAnswer', 'chatMember', 'myChatMember', 'chatJoinRequest', 'chatBoost', 'removedChatBoost']);
