import { AnimationAttachment, Attachment, AudioAttachment, ContactAttachment, DocumentAttachment, LocationAttachment, PhotoAttachment, PollAttachment, StickerAttachment, StoryAttachment, VenueAttachment, VideoAttachment, VideoNoteAttachment, VoiceAttachment } from '../common/attachments';
import { MediaGroup } from '../common/media-group';
import { Message, MessageEntity } from '../common/structures';
import * as Interfaces from '../generated/telegram-interfaces';
import { Telegram } from '../telegram';
import { AttachmentType as AttachmentTypeEnum, EntityType } from '../types/enums';
import { AttachmentsMapping } from '../types/mappings';
import { AttachmentType, Constructor, Require, RequireValue, UpdateName } from '../types/types';
import { Context } from './context';
import { DownloadMixin, ChatControlMixin, ChatInviteControlMixin, ChatMemberControlMixin, ChatSenderControlMixin, CloneMixin, NodeMixin, PinsMixin, SendMixin, ChatActionMixin, TargetMixin } from './mixins';
interface MessageContextOptions {
    telegram: Telegram;
    update?: Interfaces.TelegramUpdate;
    payload: Interfaces.TelegramMessage;
    updateId?: number;
    type?: UpdateName;
}
/** Called when `message` event occurs */
declare class MessageContext extends Context {
    #private;
    payload: Interfaces.TelegramMessage;
    mediaGroup?: MediaGroup;
    constructor(options: MessageContextOptions);
    /**
     * For text messages, the actual UTF-8 text of the message, 0-4096 characters
     */
    get text(): string | undefined;
    set text(text: string | undefined);
    /** Checks if the message has `text` property */
    hasText(): this is Require<this, 'text'>;
    /**
     * Caption for the animation, audio, document, photo, video or voice,
     * 0-1024 characters
     */
    get caption(): string | undefined;
    set caption(caption: string | undefined);
    /** Checks if the message has `caption` property */
    hasCaption(): this is Require<this, 'caption'>;
    /** Checks if the message has `dice` property */
    hasDice(): this is Require<this, 'dice'>;
    /** Value after the `/start` command */
    get rawStartPayload(): string | undefined;
    /** Parsed value after the `/start` command */
    get startPayload(): any;
    /** Does this message have start payload? */
    hasStartPayload(): this is Require<this, 'startPayload'>;
    /** Checks if the message has `author_signature` property */
    hasAuthorSignature(): this is Require<this, 'authorSignature'>;
    /** Checks if there are any entities (with specified type) */
    hasEntities(type?: EntityType | MessageEntity['type']): this is Require<this, 'entities'>;
    /** Checks if there are any caption entities (with specified type) */
    hasCaptionEntities(type?: EntityType | MessageEntity['type']): this is Require<this, 'captionEntities'>;
    /** Checks whether current message contains a media group (`mergeMediaEvents` must be on) */
    isMediaGroup(): this is Require<this, 'mediaGroupId' | 'mediaGroup'>;
    /** Message attachment */
    get attachment(): AnimationAttachment | AudioAttachment | ContactAttachment | DocumentAttachment | LocationAttachment | PhotoAttachment | StickerAttachment | StoryAttachment | VideoAttachment | VideoNoteAttachment | VoiceAttachment | PollAttachment | VenueAttachment | undefined;
    /** Does this message have an attachment with a specific type `type`? */
    hasAttachmentType<T extends AttachmentType>(type: T): this is RequireValue<this, 'attachment', AttachmentsMapping[T]>;
    /** Does this message even have an attachment? */
    hasAttachment(): this is Require<this, 'attachment'>;
    /** Is this message a giveaway */
    isGiveaway(): this is Require<this, 'giveaway'>;
    /** Is this message an event? */
    isEvent(): boolean;
    /** Event type */
    get eventType(): import("../types/types").MessageEventName | undefined;
    /** Is this message a service one? */
    isServiceMessage(): boolean;
    /** Does this message have a forward origin? */
    hasForwardOrigin(): this is Require<this, 'forwardOrigin'>;
    /** Is this message a forwarded one? */
    isForwarded(): this is Require<this, 'forwardedMessage'>;
    /** Does this message have a quote? */
    hasQuote(): this is Require<this, 'quote'>;
    /** Does this message have link preview options? */
    hasLinkPreviewOptions(): this is Require<this, 'linkPreviewOptions'>;
    /** Does this message have external reply info? */
    hasReplyInfo(): this is Require<this, 'externalReply'>;
    /** Does this message have external reply info? An alias for `hasReplyInfo()` */
    hasExternalReply(): this is Require<this, 'externalReply'>;
    /** Does this message have reply message? */
    hasReplyToMessage(): this is Require<this, 'replyToMessage'>;
    /**
     * Does this message have reply message?
     *
     * @deprecated use `hasReplyToMessage` instead
     */
    hasReplyMessage(): this is Require<this, 'replyToMessage'>;
    /** Checks if the sent message has `via_bot` property */
    hasViaBot(): this is Require<this, 'viaBot'>;
    /** Does this message have a reply to story? */
    hasReplyToStory(): this is Require<this, 'replyToStory'>;
    /**
     * Does this message have a reply to story?
     *
     * @deprecated use `hasReplyToStory` instead
     */
    hasReplyStory(): this is Require<this, 'replyToStory'>;
    /** @deprecated use `attachment` instead */
    get attachments(): Attachment[];
    /** @deprecated use `hasAttachmentType(type)` and `hasAttachment` instead */
    hasAttachments(type?: AttachmentType | AttachmentTypeEnum): boolean;
    /** @deprecated */
    getAttachments(type: AttachmentTypeEnum.Animation | 'animation'): AnimationAttachment[];
    getAttachments(type: AttachmentTypeEnum.Audio | 'audio'): AudioAttachment[];
    getAttachments(type: AttachmentTypeEnum.Contact | 'contact'): ContactAttachment[];
    getAttachments(type: AttachmentTypeEnum.Document | 'document'): DocumentAttachment[];
    getAttachments(type: AttachmentTypeEnum.Location | 'location'): LocationAttachment[];
    getAttachments(type: AttachmentTypeEnum.Photo | 'photo'): PhotoAttachment[];
    getAttachments(type: AttachmentTypeEnum.Poll | 'poll'): PollAttachment[];
    getAttachments(type: AttachmentTypeEnum.Sticker | 'sticker'): StickerAttachment[];
    getAttachments(type: AttachmentTypeEnum.Story | 'story'): StoryAttachment[];
    getAttachments(type: AttachmentTypeEnum.Venue | 'venue'): VenueAttachment[];
    getAttachments(type: AttachmentTypeEnum.Video | 'video'): VideoAttachment[];
    getAttachments(type: AttachmentTypeEnum.VideoNote | 'video_note'): VideoNoteAttachment[];
    getAttachments(type: AttachmentTypeEnum.Voice | 'voice'): VoiceAttachment[];
    getAttachments(type?: AttachmentType | AttachmentTypeEnum): Attachment[];
    /** @deprecated use `isForwarded` instead */
    get isForward(): () => this is Require<this, "forwardedMessage">;
}
interface MessageContext extends Constructor<MessageContext>, Message, TargetMixin, SendMixin, ChatActionMixin, NodeMixin, DownloadMixin, ChatInviteControlMixin, ChatControlMixin, ChatSenderControlMixin, ChatMemberControlMixin, PinsMixin, CloneMixin<MessageContext, MessageContextOptions> {
}
export { MessageContext };
