import * as Methods from '../../generated/methods';
import { Optional } from '../../types/types';
import { Poll } from '../../common/structures';
import type { tSendMethods } from '../../types/send-media';
import { MessageContext } from '../message';
import { Context } from '../context';
interface SendMixinMetadata {
    get chatId(): number;
    get senderId(): number | undefined;
}
/** This object represents a mixin which can invoke `chatId`/`senderId`-dependent methods */
declare class SendMixin {
    /** Sends message to current chat */
    send(text: Methods.SendMessageParams['text'], params?: Optional<Methods.SendMessageParams, 'chat_id' | 'text'>): Promise<MessageContext>;
    /** Sends photo to current chat */
    sendPhoto(photo: Methods.SendPhotoParams['photo'], params?: Optional<Methods.SendPhotoParams, 'chat_id' | 'photo'>): Promise<MessageContext>;
    /** Sends document to current chat */
    sendDocument(document: Methods.SendDocumentParams['document'], params?: Optional<Methods.SendDocumentParams, 'chat_id' | 'document'>): Promise<MessageContext>;
    /** Sends audio to current chat */
    sendAudio(audio: Methods.SendAudioParams['audio'], params?: Optional<Methods.SendAudioParams, 'chat_id' | 'audio'>): Promise<MessageContext>;
    /** Sends video to current chat */
    sendVideo(video: Methods.SendVideoParams['video'], params?: Optional<Methods.SendVideoParams, 'chat_id' | 'video'>): Promise<MessageContext>;
    /** Sends animation to current chat */
    sendAnimation(animation: Methods.SendAnimationParams['animation'], params?: Optional<Methods.SendAnimationParams, 'chat_id' | 'animation'>): Promise<MessageContext>;
    /** Sends video note to current chat */
    sendVideoNote(videoNote: Methods.SendVideoNoteParams['video_note'], params?: Optional<Methods.SendVideoNoteParams, 'chat_id' | 'video_note'>): Promise<MessageContext>;
    /** Sends voice to current chat */
    sendVoice(voice: Methods.SendVoiceParams['voice'], params?: Optional<Methods.SendVoiceParams, 'chat_id' | 'voice'>): Promise<MessageContext>;
    /** Sends location to current chat */
    sendLocation(latitude: number, longitude: number, params?: Optional<Methods.SendLocationParams, 'chat_id' | 'latitude' | 'longitude'>): Promise<MessageContext>;
    /** Sends invoice to current user */
    sendInvoice(params: Optional<Methods.SendInvoiceParams, 'chat_id'>): Promise<MessageContext>;
    /** Sends venue to current chat */
    sendVenue(params: Optional<Methods.SendVenueParams, 'chat_id'>): Promise<MessageContext>;
    /** Sends contact to current chat */
    sendContact(params: Optional<Methods.SendContactParams, 'chat_id'>): Promise<MessageContext>;
    /** Sends poll to current chat */
    sendPoll(params: Optional<Methods.SendPollParams, 'chat_id'>): Promise<MessageContext>;
    /** Sends sticker */
    sendSticker(sticker: Methods.SendStickerParams['sticker'], params?: Optional<Methods.SendStickerParams, 'sticker' | 'chat_id'>): Promise<MessageContext>;
    /** Stops poll in current chat */
    stopPoll(messageId: number, params?: Partial<Methods.StopPollParams>): Promise<Poll>;
    /** Sends chat action to current chat */
    sendChatAction(action: Methods.SendChatActionParams['action'], params?: Optional<Methods.SendChatActionParams, 'chat_id' | 'action'>): Promise<true>;
    /** Sends dice */
    sendDice(emoji: Methods.SendDiceParams['emoji'], params?: Partial<Methods.SendDiceParams>): Promise<MessageContext>;
    /** Sends media group to current chat */
    sendMediaGroup(mediaGroup: Methods.SendMediaGroupParams['media'], params?: Optional<Methods.SendMediaGroupParams, 'chat_id' | 'media'>): Promise<MessageContext[]>;
    /**
     * Automatically uses correct media method to send media
     *
     * @example
     * ```js
     * context.sendMedia({
     *   type: 'photo',
     *   photo: MediaSource.path('./image.png'),
     *   caption: 'good image yes yes'
     * })
     * ```
     */
    sendMedia<T extends string>(query: {
        type: T;
    } & tSendMethods): ReturnType<T extends 'animation' ? typeof this.sendAnimation : T extends 'audio' ? typeof this.sendAudio : T extends 'document' ? typeof this.sendDocument : T extends 'photo' ? typeof this.sendPhoto : T extends 'sticker' ? typeof this.sendSticker : T extends 'video_note' ? typeof this.sendVideoNote : T extends 'video' ? typeof this.sendVideo : T extends 'voice' ? typeof this.sendVoice : () => never>;
    sendMedia<T extends {
        type: string;
    }>(media: T): ReturnType<T extends {
        type: 'animation';
    } ? typeof this.sendAnimation : T extends {
        type: 'audio';
    } ? typeof this.sendAudio : T extends {
        type: 'document';
    } ? typeof this.sendDocument : T extends {
        type: 'photo';
    } ? typeof this.sendPhoto : T extends {
        type: 'sticker';
    } ? typeof this.sendSticker : T extends {
        type: 'video_note';
    } ? typeof this.sendVideoNote : T extends {
        type: 'video';
    } ? typeof this.sendVideo : T extends {
        type: 'voice';
    } ? typeof this.sendVoice : () => never>;
    /** Returns chat boosts by the user */
    getChatBoosts(userId: number): Promise<import("../../generated").TelegramUserChatBoosts>;
}
interface SendMixin extends Context, SendMixinMetadata {
}
export { SendMixin };
