/// <reference types="node" />
import { MediaInputTo, MediaSourceToBuffer, MediaSourceToPath, MediaSourceToStream } from './common/media-source';
import { User } from './common/structures/user';
import { ApiMethods } from './generated';
import { Updates } from './updates';
import { ApiResponseError, TelegramOptions } from './types/interfaces';
import { ApiMethod, SoftString } from './types/types';
import * as Hooks from './types/hooks';
import { Attachment } from './common/attachments';
interface APICallMethod {
    /** Use this method to invoke Telegram Bot API `method` [with prompted `params`] */
    call: (method: SoftString<ApiMethod>, params?: Record<string, any>) => Promise<any>;
}
interface SuppressAddition<B> {
    /**
     * Pass `true` if you don't want failed API requests to throw an error.
     * Instead, in those cases, the method will return `ApiResponseError`.
     *
     * @default false
     */
    suppress?: B;
}
type SuppressMethodReturnType<R, B extends boolean | undefined> = void extends R ? void : undefined extends B ? R : false extends B ? R : R | ApiResponseError;
type SuppressedMethodParams<P, B extends boolean | undefined> = P & SuppressAddition<B>;
type IsSuppressedMethodParamsNullable<P> = unknown extends P ? true : undefined extends P ? true : false;
type SuppressedMethod<M extends (p?: any) => Promise<any>> = M extends (p: infer P) => Promise<infer R> ? true extends IsSuppressedMethodParamsNullable<P> ? <B extends boolean | undefined>(params?: SuppressedMethodParams<P, B>) => Promise<SuppressMethodReturnType<R, B>> : <B extends boolean | undefined>(params: SuppressedMethodParams<P, B>) => Promise<SuppressMethodReturnType<R, B>> : never;
type SuppressableApiMethods = {
    [K in keyof ApiMethods]: SuppressedMethod<ApiMethods[K]>;
};
type ProxyAPIMethods = APICallMethod & SuppressableApiMethods;
/**
 * Telegram class. Actually, this class is a set of other classes such as `Updates` and (uh that's it. `api` is not a class, it's a `Proxy` object :P)
 */
export declare class Telegram {
    options: TelegramOptions;
    /**
     * API Proxy object
     *
     * @example
     * ```js
     * telegram.api.getMe()
     * telegram.api.sendMessage({ chat_id, text })
     * telegram.api.call('sendPhoto', { chat_id, photo })
     * ```
     */
    readonly api: ProxyAPIMethods;
    /** Updates instance */
    updates: Updates;
    /** Bot data. You are able to access it only after `updates.startPolling()` succeeded! */
    bot: User;
    protected hooks: Hooks.Hooks;
    constructor(options?: Partial<TelegramOptions>);
    /** Creates `Telegram` instance just from `token` [and `params`] */
    static fromToken(token: string, options?: Partial<TelegramOptions>): Telegram;
    /**
     * Returns `true` if the provided `data` is an `ApiResponseError`.
     * Useful when dealing with `suppress: true` parameter when calling API methods.
     *
     * @example
     * const result = await context.sendChatAction('typing', { suppress: true })
     *
     * if (Telegram.isErrorResponse(result)) {
     *   // TODO
     * }
     */
    static isErrorResponse(data: any): data is ApiResponseError;
    /**
     * Executes `method` with provided `params` without creating a `Telegram` instance.
     * Useful when you don't have an instance hanging around and don't need to create it.
     */
    static execute<Method extends ApiMethod>(token: string, method: Method, ...args: Parameters<ApiMethods[Method]>): ReturnType<ApiMethods[Method]>;
    /** Hook that is processed first before anything has even been set up */
    onBeforeRequest(fn: Hooks.OnBeforeRequestHandler): void;
    /** Hook that is executed right before the API call is made  */
    onRequestIntercept(fn: Hooks.OnRequestInterceptHandler): void;
    /** Once the response is received from the API, this hook will be executed */
    onResponseIntercept(fn: Hooks.OnResponseInterceptHandler): void;
    /** After everything has been done, this hook is called */
    onAfterRequest(fn: Hooks.OnAfterRequestHandler): void;
    /** If an API error has happened, this hook will be triggered */
    onError(fn: Hooks.OnErrorHandler): void;
    /**
     * Applies a set of hooks. Useful when reusing a bunch of hooks
     *
     * The order of processing hooks:
     * 1. `onBeforeRequest`
     * 2. `onRequestIntercept`
     * 3. API request
     * 4. `onResponseIntercept`
     * 5. `onAfterRequest`
     *
     * On top of that, `onError` works across `onRequestIntercept` to `onAfterRequest`
     */
    useHooks(hooks: Partial<Hooks.Hooks>): void;
    /**
     * Downloads file from Telegram servers
     *
     * @example
     * const buffer = await telegram.downloadFile(context.attachment, MediaSourceTo.buffer())
     */
    downloadFile(attachment: Attachment, to?: MediaSourceToBuffer): Promise<Buffer | null>;
    downloadFile(attachment: Attachment, to: MediaSourceToPath): Promise<void | null>;
    downloadFile(attachment: Attachment, to: MediaSourceToStream): Promise<void | null>;
    downloadFile(attachment: Attachment, to: MediaInputTo): Promise<Buffer | void | null>;
    downloadFile(fileId: string, to?: MediaSourceToBuffer): Promise<Buffer | null>;
    downloadFile(fileId: string, to: MediaSourceToPath): Promise<void | null>;
    downloadFile(fileId: string, to: MediaSourceToStream): Promise<void | null>;
    downloadFile(fileId: string, to: MediaInputTo): Promise<Buffer | void | null>;
    getFileURL(path: string): string;
    getAttachmentURL(fileId: string): Promise<string | null>;
    /** @deprecated */
    setOptions(options: Partial<TelegramOptions>): this;
    /** Resolves `MediaInput` into a `File` or `string` */
    private createMediaInput;
    /** Uploads media as usual, returning `RequestInit` */
    private uploadMedia;
    /** Validates media and creates it under `attach://<attach-id>` ID if necessary */
    private createAttachMediaInput;
    /**
     * `uploadWithMedia` shares the same logic under the hood for both `sendMediaGroup` and `editMessageMedia`.
     * This method keeps it separate yet organic at the same time
     */
    private processUploadWithMedia;
    /**
     * Methods like `sendMediaGroup` and `editMessageMedia` has `media: MediaInput` (or `media: MediaInput[]`) properties.
     * This method makes it so this `media` property is handled properly
     */
    private uploadWithMedia;
    /** Runs specific hooks */
    private runHooks;
    /** Invokes Telegram Bot API `path` method [with `params`] */
    private _callAPI;
    /**
     * Call API `method` with `params`
     * @deprecated use `telegram.api.call(...)` instead
     */
    callApi(method: string, params?: Record<string, any>): Promise<any>;
}
export {};
