"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Telegram = void 0;
const node_stream_1 = require("node:stream");
const node_util_1 = require("node:util");
const promises_1 = require("node:fs/promises");
const debug_1 = require("debug");
const form_data_encoder_1 = require("form-data-encoder");
const formdata_node_1 = require("formdata-node");
const file_from_path_1 = require("formdata-node/file-from-path");
const inspectable_1 = require("inspectable");
const undici_1 = require("undici");
const media_source_1 = require("./common/media-source");
const errors_1 = require("./errors");
const updates_1 = require("./updates");
const constants_1 = require("./utils/constants");
const helpers_1 = require("./utils/helpers");
const attachments_1 = require("./common/attachments");
const $debugger = (0, debug_1.debug)('puregram:api');
const getAttachmentFileId = (attachment) => {
    if (attachment instanceof attachments_1.PhotoAttachment) {
        return attachment.bigSize.fileId;
    }
    if (attachment instanceof attachments_1.FileAttachment) {
        return attachment.fileId;
    }
    throw new TypeError('invalid attachment provided');
};
/**
 * Telegram class. Actually, this class is a set of other classes such as `Updates` and (uh that's it. `api` is not a class, it's a `Proxy` object :P)
 */
class Telegram {
    constructor(options = {}) {
        this.options = { ...constants_1.DEFAULT_OPTIONS };
        /**
         * API Proxy object
         *
         * @example
         * ```js
         * telegram.api.getMe()
         * telegram.api.sendMessage({ chat_id, text })
         * telegram.api.call('sendPhoto', { chat_id, photo })
         * ```
         */
        this.api = new Proxy({}, {
            get: (_target, method) => (...args) => {
                // INFO: `telegram.api.call(path: string, params?: Record<string, any>)`
                if (method === 'call') {
                    const path = args[0];
                    const params = args[1];
                    return this._callAPI(path, params);
                }
                return this._callAPI(method, args[0]);
            }
        });
        /** Updates instance */
        this.updates = new updates_1.Updates(this);
        this.hooks = {
            onBeforeRequest: [],
            onRequestIntercept: [],
            onResponseIntercept: [],
            onAfterRequest: [],
            onError: []
        };
        Object.assign(this.options, options);
        this.callApi = (0, node_util_1.deprecate)(Telegram.prototype.callApi, '`callApi` is deprecated and will be removed in the next major update, use `api.call` instead', 'puregram');
        this.setOptions = (0, node_util_1.deprecate)(Telegram.prototype.setOptions, '`setOptions` is deprecated and will be removed in the next major update', 'puregram');
    }
    /** Creates `Telegram` instance just from `token` [and `params`] */
    static fromToken(token, options = {}) {
        return new Telegram({
            token,
            ...options
        });
    }
    /**
     * Returns `true` if the provided `data` is an `ApiResponseError`.
     * Useful when dealing with `suppress: true` parameter when calling API methods.
     *
     * @example
     * const result = await context.sendChatAction('typing', { suppress: true })
     *
     * if (Telegram.isErrorResponse(result)) {
     *   // TODO
     * }
     */
    static isErrorResponse(data) {
        return (0, helpers_1.isPlainObject)(data) && 'ok' in data && data.ok === false && 'error_code' in data;
    }
    /**
     * Executes `method` with provided `params` without creating a `Telegram` instance.
     * Useful when you don't have an instance hanging around and don't need to create it.
     */
    static execute(token, method, ...args) {
        return Telegram.fromToken(token).api.call(method, ...args);
    }
    /** Hook that is processed first before anything has even been set up */
    onBeforeRequest(fn) {
        this.hooks.onBeforeRequest.push(fn);
    }
    /** Hook that is executed right before the API call is made  */
    onRequestIntercept(fn) {
        this.hooks.onRequestIntercept.push(fn);
    }
    /** Once the response is received from the API, this hook will be executed */
    onResponseIntercept(fn) {
        this.hooks.onResponseIntercept.push(fn);
    }
    /** After everything has been done, this hook is called */
    onAfterRequest(fn) {
        this.hooks.onAfterRequest.push(fn);
    }
    /** If an API error has happened, this hook will be triggered */
    onError(fn) {
        this.hooks.onError.push(fn);
    }
    /**
     * Applies a set of hooks. Useful when reusing a bunch of hooks
     *
     * The order of processing hooks:
     * 1. `onBeforeRequest`
     * 2. `onRequestIntercept`
     * 3. API request
     * 4. `onResponseIntercept`
     * 5. `onAfterRequest`
     *
     * On top of that, `onError` works across `onRequestIntercept` to `onAfterRequest`
     */
    useHooks(hooks) {
        for (const [hook, handlers] of Object.entries(hooks)) {
            this.hooks[hook].push(...handlers);
        }
    }
    async downloadFile(attachment, to = media_source_1.MediaSourceTo.buffer()) {
        const fileId = typeof attachment === 'string'
            ? attachment // assuming its fileId
            : getAttachmentFileId(attachment);
        const url = await this.getAttachmentURL(fileId);
        if (url === null) {
            return null;
        }
        let response;
        if (this.options.useLocal) {
            response = await (0, file_from_path_1.fileFromPath)(url);
        }
        else {
            response = await (0, undici_1.fetch)(url);
        }
        const ab = await response.arrayBuffer();
        const buffer = Buffer.from(ab);
        if (to.type === media_source_1.MediaSourceType.Buffer) {
            return buffer;
        }
        if (to.type === media_source_1.MediaSourceType.Path) {
            return (0, promises_1.writeFile)(to.value, buffer);
        }
        if (to.type === media_source_1.MediaSourceType.Stream) {
            to.value.write(buffer);
            to.value.end();
            return;
        }
        throw new TypeError('invalid `to` provided');
    }
    getFileURL(path) {
        if (this.options.useLocal) {
            return path;
        }
        // TODO: simplify
        return this.options.apiBaseUrl.slice(0, -4) + '/file/bot' + this.options.token + '/' + path;
    }
    async getAttachmentURL(fileId) {
        const file = await this.api.getFile({ file_id: fileId, suppress: true });
        if (Telegram.isErrorResponse(file)) {
            return null;
        }
        const url = this.getFileURL(file.file_path);
        return url;
    }
    /** @deprecated */
    setOptions(options) {
        return this;
    }
    /** Resolves `MediaInput` into a `File` or `string` */
    async createMediaInput(input) {
        var _a;
        const filename = (_a = input.filename) !== null && _a !== void 0 ? _a : 'file.dat';
        // INFO: returning file ID itself since we can't do anything with it
        if (input.type === media_source_1.MediaSourceType.FileId) {
            return input.value;
        }
        // INFO: [File] passed, return it
        if (input.type === media_source_1.MediaSourceType.File) {
            return input.value;
        }
        // INFO: creating [fs.ReadStream] from our path, returning that stream
        if (input.type === media_source_1.MediaSourceType.Path) {
            return (0, file_from_path_1.fileFromPath)(input.value, input.filename);
        }
        // INFO: convert stream into buffer and return it
        if (input.type === media_source_1.MediaSourceType.Stream) {
            const buffer = await (0, helpers_1.convertStreamToBuffer)(input.value);
            return new formdata_node_1.File([buffer], filename);
        }
        // INFO: returning buffer converted into a file
        if (input.type === media_source_1.MediaSourceType.Buffer) {
            return new formdata_node_1.File([input.value], filename);
        }
        // INFO: [ArrayBufferLike] passed, convert into a [File] and return in
        if (input.type === media_source_1.MediaSourceType.ArrayBuffer) {
            return new formdata_node_1.File([input.value], filename);
        }
        // INFO: fetching that URL and creating an array buffer -> file, returning that file
        // INFO: OR returning that URL right away
        if (input.type === media_source_1.MediaSourceType.Url) {
            // INFO: fetching URL contents and uploading them directly to Bot API
            if (input.forceUpload) {
                const url = input.value;
                const isURL = /^https?:\/\//i.test(url);
                if (!isURL) {
                    throw new TypeError(`'${url}' is not a valid URL`);
                }
                const response = await (0, undici_1.fetch)(url);
                const arrayBuffer = await response.arrayBuffer();
                return new formdata_node_1.File([arrayBuffer], filename);
            }
            // INFO: ... or returning that URL right away =)
            return input.value;
        }
        // @ts-expect-error user may pass invalid input.type and TypeScript does not know about it :shrug:
        throw new TypeError(`received invalid input type: ${input.type}`);
    }
    /** Uploads media as usual, returning `RequestInit` */
    async uploadMedia(params, entity) {
        const fd = new formdata_node_1.FormData();
        // INFO: clears [params] object and keeps only media values from it
        const mediaEntries = Object.entries(params).filter(([key]) => entity[1].includes(key));
        for (const [key, input] of mediaEntries) {
            // INFO: we allow only [MediaInput] media values since [puregram@2.5.0]
            if (!(0, helpers_1.isMediaInput)(input)) {
                throw new TypeError('expected media to be created via `MediaSource`');
            }
            const fdValue = await this.createMediaInput(input);
            fd.set(key, fdValue);
        }
        const encoder = new form_data_encoder_1.FormDataEncoder(fd);
        return {
            method: 'POST',
            headers: encoder.headers,
            body: node_stream_1.Readable.from(encoder)
        };
    }
    /** Validates media and creates it under `attach://<attach-id>` ID if necessary */
    async createAttachMediaInput(params) {
        const media = params.input[params.key];
        const { type: _, [params.key]: __, ...rest } = params.input;
        // INFO: we allow only [MediaInput] media values since [puregram@2.5.0]
        if (!(0, helpers_1.isMediaInput)(media)) {
            throw new TypeError('expected media to be created via `MediaSource`');
        }
        if (media.type === media_source_1.MediaSourceType.FileId || (media.type === media_source_1.MediaSourceType.Url && !media.forceUpload)) {
            // INFO: we don't need to generate `attach://` clause if we are working with file IDs or native URLs
            return { type: params.input.type, [params.key]: media.value, ...rest };
        }
        // INFO: otherwise...
        const attachId = (0, helpers_1.generateAttachId)();
        const fdValue = await this.createMediaInput(media);
        params.fd.set(attachId, fdValue);
        return { type: params.input.type, [params.key]: `attach://${attachId}`, ...rest };
    }
    /**
     * `uploadWithMedia` shares the same logic under the hood for both `sendMediaGroup` and `editMessageMedia`.
     * This method keeps it separate yet organic at the same time
     */
    async processUploadWithMedia(fd, input) {
        // INFO: [thumb] property might exist and we need to also handle it
        if (input.thumb !== undefined) {
            return this.createAttachMediaInput({ fd, input, key: 'thumb' });
        }
        return this.createAttachMediaInput({ fd, input, key: 'media' });
    }
    /**
     * Methods like `sendMediaGroup` and `editMessageMedia` has `media: MediaInput` (or `media: MediaInput[]`) properties.
     * This method makes it so this `media` property is handled properly
     */
    async uploadWithMedia(params) {
        const fd = new formdata_node_1.FormData();
        const { media } = params;
        let modifiedMedia;
        if (Array.isArray(media)) {
            // INFO: `media: MediaInput[]`, probably `sendMediaGroup`
            modifiedMedia = [];
            for (let i = 0; i < media.length; i++) {
                const input = media[i];
                modifiedMedia.push(await this.processUploadWithMedia(fd, input));
            }
        }
        else {
            // INFO: `media: MediaInput`, probably `editMessageMedia`
            modifiedMedia = await this.processUploadWithMedia(fd, media);
        }
        fd.set('media', JSON.stringify(modifiedMedia));
        const encoder = new form_data_encoder_1.FormDataEncoder(fd);
        return {
            method: 'POST',
            headers: encoder.headers,
            body: node_stream_1.Readable.from(encoder)
        };
    }
    /** Runs specific hooks */
    async runHooks(hooks, data) {
        let context = data;
        for (const hook of hooks) {
            context = await hook(context);
        }
        return context;
    }
    /** Invokes Telegram Bot API `path` method [with `params`] */
    async _callAPI(path, params = {}) {
        const controller = new AbortController();
        const timeout = setTimeout(() => controller.abort(), this.options.apiTimeout);
        const init = {
            method: 'GET',
            signal: controller.signal,
            duplex: 'half'
        };
        if (this.options.agent !== undefined) {
            init.dispatcher = this.options.agent;
        }
        const debug$api = $debugger.extend(path, '/');
        let context$beforeRequest = {
            controller,
            init,
            path,
            params
        };
        context$beforeRequest = await this.runHooks(this.hooks.onBeforeRequest, context$beforeRequest);
        // INFO: convert complex values in [params] into something readable
        // INFO: note it will remove [Buffer] and [Readable] objects
        const decomplexified = (0, helpers_1.decomplexify)(params);
        const query = new URLSearchParams(decomplexified).toString();
        const url = `${this.options.apiBaseUrl}${this.options.token}/${this.options.useTestDc ? 'test/' : ''}${path}?${query}`;
        try {
            debug$api('HTTP ›');
            // INFO: ---- detecting media methods ----
            // INFO: [sendMediaGroup] and [editMessageMedia] requires special logic
            if (['sendMediaGroup', 'editMessageMedia'].includes(path)) {
                const newInit = await this.uploadWithMedia(params);
                context$beforeRequest.init = {
                    ...init,
                    ...newInit
                };
            }
            else {
                const mediaEntity = constants_1.METHODS_WITH_MEDIA.find(entity => entity[0] === path);
                const hasMediaProperties = mediaEntity !== undefined && (Object.keys(params).some(value => mediaEntity[1].includes(value)));
                // INFO: if current [path] is a method with possible media properties
                // INFO: and we have those media properties in our [params] (not [decomplexified]!) object
                if (hasMediaProperties) {
                    const newInit = await this.uploadMedia(params, mediaEntity);
                    context$beforeRequest.init = {
                        ...init,
                        ...newInit
                    };
                }
            }
            let context$requestIntercept = {
                ...context$beforeRequest,
                query,
                url
            };
            context$requestIntercept = await this.runHooks(this.hooks.onRequestIntercept, context$requestIntercept);
            debug$api('url: %s', context$requestIntercept.url.replace(this.options.token, '[token]'));
            debug$api('params: %j', decomplexified);
            const response = await (0, undici_1.fetch)(context$requestIntercept.url, context$requestIntercept.init);
            const json = await response.json();
            let context$responseIntercept = {
                ...context$requestIntercept,
                response,
                json
            };
            context$responseIntercept = await this.runHooks(this.hooks.onResponseIntercept, context$responseIntercept);
            debug$api('‹ HTTP %d', response.status);
            debug$api('response: %j', json);
            if (!json.ok && params.suppress === true) {
                return json;
            }
            else if (!json.ok) {
                throw new errors_1.APIError(json);
            }
            let context$afterRequest = {
                ...context$responseIntercept
            };
            context$afterRequest = await this.runHooks(this.hooks.onAfterRequest, context$afterRequest);
            return context$afterRequest.json.result;
        }
        catch (error) {
            let context$error = {
                error: error
            };
            context$error = await this.runHooks(this.hooks.onError, context$error);
            throw context$error.error;
        }
        finally {
            clearTimeout(timeout);
        }
    }
    /**
     * Call API `method` with `params`
     * @deprecated use `telegram.api.call(...)` instead
     */
    callApi(method, params) {
        return this.api.call(method, params);
    }
}
exports.Telegram = Telegram;
(0, inspectable_1.inspectable)(Telegram, {
    serialize(telegram) {
        return {
            options: {
                token: telegram.options.token ? '[set]' : '[none]',
                apiBaseUrl: telegram.options.apiBaseUrl
            },
            updates: telegram.updates
        };
    }
});
